@@ -193,13 +193,16 @@ class Request(object):
 
         return self.send(self.__protobuf_types.encode(param_save_msg))
 
-    def setParameter(self, path, value, type_name=None):
+    def setParameter(self, path, value, type_name=None, offset=0, length=0):
         """Set new value to a parameter with given path
 
             Args:
                 path(str): parameter path in the tree
                 value(any): new parameter value
                 type_name(str): type of the value (by default resolved automatically)
+                offset(int): offset of the elements to update in the destination array, (by default is 0)
+                length(int): number of the elements to update in the destination array, (by default takes length of the
+                value argument)
 
             Returns:
                   Reply(StatusMsg): A Promise, which resolves when parameter value is updated or fails otherwise.
@@ -211,9 +214,15 @@ class Request(object):
                   >>> reply.get()
         """
 
-        return self.send(self.__protobuf_types.encode(self.__buildSetParameterMsg(path, value,
-                                                                                  type_name, self.__protobuf_types,
-                                                                                  self.__parameter_tree)))
+        if (offset == 0) and (length == 0):
+            return self.send(self.__protobuf_types.encode(self.__buildSetParameterMsg(path, value,
+                                                                                      type_name, self.__protobuf_types,
+                                                                                      self.__parameter_tree)))
+        else:
+            return self.send(
+                self.__protobuf_types.encode(self.__buildSetParameterWithOffsetMsg(offset, length, path, value,
+                                                                                   type_name, self.__protobuf_types,
+                                                                                   self.__parameter_tree)))
 
     def setParameterList(self, param_list):
         """Set new values to a parameter list
@@ -391,6 +400,43 @@ class Request(object):
 
         return set_param_msg
 
+    @staticmethod
+    def __buildSetParameterWithOffsetMsg(offset, length, path, value, type_name, protobuf_types, parameter_tree):
+        param_value = None
+        if not type_name:
+            type_id = parameter_tree.getDataType(path)
+            if type_id:
+                param_value = protobuf_types.getTypeByHash(type_id)
+        else:
+            param_value = protobuf_types.createType(type_name)
+
+        if not param_value:
+            logger.error("Failed to find encoder for the path: %s type: %s" % (path, type_name))
+
+        # check an offset
+        if offset < 0:
+            offset = 0
+
+        # check length, if == 0 assign length of the value
+        if length < 0:
+            length = 0
+        if length == 0:
+            if hasattr(value, '__len__'):
+                length = len(value)
+            else:
+                length = 1
+
+        # creating type instance
+        set_param_msg = protobuf_types.createType("motorcortex.SetParameterMsg")
+        set_param_msg.offset.type = 1
+        set_param_msg.offset.offset = offset
+        set_param_msg.offset.length = length
+        set_param_msg.path = path
+        # encoding parameter value
+        set_param_msg.value = param_value.encode(value)
+
+        return set_param_msg
+
     @staticmethod
     def __buildGetParameterMsg(path, protobuf_types):
         # getting and instantiating data type from the loaded dict
