@@ -111,7 +111,7 @@ class Reconnection(unittest.TestCase):
 
         # Open request connection
         req, sub = motorcortex.connect("wss://127.0.0.1:5568:5567", motorcortex_types, parameter_tree,
-                                       certificate="mcx.cert.pem", timeout_ms=5000,
+                                       certificate="mcx.cert.crt", timeout_ms=5000,
                                        login="root", password="vectioneer")
 
         sub.subscribe(["root/Comm_task/actual_cycle_max"], "test", 2000).notify(lambda x: print(f"1:{x}"))
@@ -235,7 +235,7 @@ class ParameterTree(unittest.TestCase):
         # logging.basicConfig(level=logging.INFO)
         # Open request connection
         req, sub = motorcortex.connect("wss://localhost:5568:5567", motorcortex_types, parameter_tree,
-                                       certificate="mcx.cert.pem", timeout_ms=1000, login="", password="")
+                                       certificate="mcx.cert.crt", timeout_ms=1000, login="", password="")
 
         path = tempfile.gettempdir() + '/' + 'mcx-python-ParameterTree-hash'
         tree = req.getParameterTree().get()
@@ -312,7 +312,7 @@ class OverwriteReleaseParameter(unittest.TestCase):
 
         # Open request connection
         req, sub = motorcortex.connect("wss://127.0.0.1:5568:5567", motorcortex_types, parameter_tree,
-                                       certificate="mcx.cert.pem", timeout_ms=5000,
+                                       certificate="mcx.cert.crt", timeout_ms=5000,
                                        login="root", password="vectioneer")
 
         ## test non-existing path
@@ -383,7 +383,7 @@ class StreamTest(unittest.TestCase):
 
         # Open request connection
         req, sub = motorcortex.connect("ws://localhost:5558:5557", motorcortex_types, parameter_tree,
-                                       certificate="mcx.cert.pem", timeout_ms=5000,
+                                       certificate="mcx.cert.crt", timeout_ms=5000,
                                        login="", password="")
 
         subscription = sub.subscribe(["root/Comm_task/utilization_max",
@@ -426,7 +426,7 @@ class ConnectionTimeout(unittest.TestCase):
 
         # Open request connection
         req, sub = motorcortex.connect("wss://localhost:5568:5567", motorcortex_types, parameter_tree,
-                                       certificate="mcx.cert.pem", timeout_ms=5000,
+                                       certificate="mcx.cert.crt", timeout_ms=5000,
                                        login="test", password="test", state_update=self.stateChange)
 
         while True:
@@ -449,7 +449,7 @@ class GetParameter(unittest.TestCase):
 
         # Open request connection
         req, sub = motorcortex.connect("wss://192.168.179.85:5568:5567", motorcortex_types, parameter_tree,
-                                       certificate="mcx.cert.pem", timeout_ms=5000,
+                                       certificate="mcx.cert.crt", timeout_ms=5000,
                                        login="test", password="test")
 
         rep = req.getParameterList(["root/Logic/mode",
@@ -474,7 +474,7 @@ class SubParameter(unittest.TestCase):
 
         parameter_tree = motorcortex.ParameterTree()
         req = motorcortex.Request(motorcortex_types, parameter_tree)
-        if req.connect("wss://%s:5568" % SERVER, certificate="mcx.cert.pem").get(5000):
+        if req.connect("wss://%s:5568" % SERVER, certificate="mcx.cert.crt").get(5000):
             print("Request connection is etablished")
         else:
             print("Failed to establish Request connection")
@@ -499,7 +499,7 @@ class SubParameter(unittest.TestCase):
             self.assertTrue(False)
 
         sub = motorcortex.Subscribe(req, motorcortex_types)
-        if sub.connect("wss://%s:5567" % SERVER, certificate="mcx.cert.pem").get(1000):
+        if sub.connect("wss://%s:5567" % SERVER, certificate="mcx.cert.crt").get(1000):
             print("Subscribe connection is etablished")
         else:
             print("Failed to establish Subscribe connection")
@@ -531,7 +531,7 @@ class SetString(unittest.TestCase):
         parameter_tree = motorcortex.ParameterTree()
         # Open request and subscribe connection
         req, sub = motorcortex.connect("wss://localhost:5568:5567", motorcortex.MessageTypes(), parameter_tree,
-                                       certificate="mcx.cert.pem", timeout_ms=1000,
+                                       certificate="mcx.cert.crt", timeout_ms=1000,
                                        login="root", password="secret")
         res = req.setParameter("root/Control/dummyChar", "Hallo robot!")
         res.get()
@@ -542,7 +542,7 @@ class SetParameterWithOffset(unittest.TestCase):
         parameter_tree = motorcortex.ParameterTree()
         # Open request and subscribe connection
         req, sub = motorcortex.connect("wss://localhost:5568:5567", motorcortex.MessageTypes(), parameter_tree,
-                                       certificate="mcx.cert.pem", timeout_ms=1000,
+                                       certificate="mcx.cert.crt", timeout_ms=1000,
                                        login="root", password="secret")
         res = req.setParameter("root/Control/hostInJointTrajectory", [6, 5])
         res.get()
