@@ -25,7 +25,7 @@ if __name__ == '__main__':
 
     threads = []
     for i in range(50):
-        threads.append(threading.Thread(target=test, args=(i, 'wss://localhost:5555', 'mcx.cert.pem')))
+        threads.append(threading.Thread(target=test, args=(i, 'wss://localhost:5555', 'mcx.cert.crt')))
         threads[-1].start()
         time.sleep(0.01)
 
